Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(323)

Unified Diff: third_party/npapi/bindings/nptypes.h

Issue 6102007: Update NPAPI headers to r32 from the upstream npapi-headers repository (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Add nptypes.h changes Created 9 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/npapi/bindings/npfunctions.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/npapi/bindings/nptypes.h
diff --git a/third_party/npapi/bindings/nptypes.h b/third_party/npapi/bindings/nptypes.h
index e8a139173fcb268d2d963a9fe97b761de78c5e76..300128885cc346745bdba87f871674dcfc5e231a 100644
--- a/third_party/npapi/bindings/nptypes.h
+++ b/third_party/npapi/bindings/nptypes.h
@@ -40,19 +40,21 @@
#define nptypes_h_
/*
* Header file for ensuring that C99 types ([u]int32_t and bool) and
* true/false macros are available.
*/
#if defined(WIN32) || defined(OS2)
/*
- * Win32 and OS/2 don't know C99, so define [u]int_16/32 here. The bool
+ * Win32 and OS/2 don't know C99, so define [u]int_16/32/64 here. The bool
* is predefined tho, both in C and C++.
*/
typedef short int16_t;
typedef unsigned short uint16_t;
typedef int int32_t;
typedef unsigned int uint32_t;
+ typedef long long int64_t;
+ typedef unsigned long long uint64_t;
#elif defined(_AIX) || defined(__sun) || defined(__osf__) || defined(IRIX) || defined(HPUX)
/*
* AIX and SunOS ship a inttypes.h header that defines [u]int32_t,
@@ -77,6 +79,7 @@
*/
#if defined(bsdi)
typedef u_int32_t uint32_t;
+ typedef u_int64_t uint64_t;
#if !defined(__cplusplus)
typedef int bool;
« no previous file with comments | « third_party/npapi/bindings/npfunctions.h ('k') | no next file » | no next file with comments »
@@ -40,19 +40,21 @@
#define nptypes_h_
/*
- * Header file for ensuring that C99 types ([u]int32_t and bool) and
+ * Header file for ensuring that C99 types ([u]int32_t, [u]int64_t and bool) and
* true/false macros are available.
*/

Powered by Google App Engine
This is Rietveld 408576698